ImageProcessor class

Процессор изображений - аналог ImageMagick для Flutter

Constructors

ImageProcessor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertToPng32(String inputPath, String outputPath) → Future<void>
Конвертация изображения в PNG32
createPlaceholder(String inputPath, String outputPath, int maxSize) → Future<void>
Создание placeholder изображения
createTiles(String inputPath, String outputTemplate, int tileSize) → Future<void>
Создание тайлов из изображения
getImageSize(String filePath) → Future<Size>
Получение размеров изображения
resizeImage(String inputPath, String outputPath, int width, int height) → Future<void>
Изменение размера изображения