ZipUtils class

Утилиты для работы с ZIP архивами

Constructors

ZipUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

unzip(String srcPath, String dstPath) → Future<void>
Распаковка ZIP архива
zip(String srcPath, String dstPath, {int compressionLevel = 5}) → Future<void>
Создание ZIP архива