AnimationState class

Состояние анимации

Constructors

AnimationState({required double translateX, required double translateY, required double rotation, required double scaleX, required double scaleY, required double alpha})

Properties

alpha → double
final
hashCode → int
The hash code for this object.
no setterinherited
rotation → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleX → double
final
scaleY → double
final
translateX → double
final
translateY → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited